@@ -37,7 +37,6 @@
 #include "ephy-type-builtins.h"
 
 #include <glib/gi18n.h>
-#define HANDY_USE_UNSTABLE_API
 #include <handy.h>
 
 enum {
@@ -209,6 +208,7 @@ ephy_header_bar_constructed (GObject *object)
   }
 
   event_box = gtk_event_box_new ();
+  gtk_widget_add_events (event_box, GDK_ALL_EVENTS_MASK);
   gtk_widget_show (event_box);
   gtk_header_bar_set_custom_title (GTK_HEADER_BAR (header_bar), event_box);
   gtk_widget_set_name (event_box, "title-box-container");
